@@ -18,6 +18,10 @@ function(replist,subplots=1:7,
   pngfun <- function(file) png(file=file,width=pwidth,height=pheight,units=punits,res=res,pointsize=ptsize)
 
   cpue        <- replist$cpue
+  if(is.null(dim(cpue))){
+    cat("no CPUE data in this model\n")
+    return()
+  }
   FleetNames  <- replist$FleetNames
   nfleets     <- replist$nfleets
   if(plotdir=="default") plotdir <- replist$inputs$dir
